@@ -1,5 +1,7 @@
 import re
 import string
+import subprocess
+import sys
 import unicodedata
 from os import listdir
 from os.path import isfile, join
